_thrift
========

* This directory is auto-generated by Thrift Compiler by using 
  https://github.com/twitter/zipkin/blob/master/zipkin-thrift/src/main/thrift/com/twitter/zipkin/zipkinCore.thrift 
 
* Do not modify this directory.

